"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("stryker-api/core");
var babel = require("babel-core");
var path = require("path");
var os_1 = require("os");
var BabelConfigReader_1 = require("./BabelConfigReader");
var BabelTranspiler = /** @class */ (function () {
    function BabelTranspiler(options) {
        this.babelConfig = new BabelConfigReader_1.default().readConfig(options.config);
        this.knownExtensions = ['.js', '.jsx'];
    }
    BabelTranspiler.prototype.transpile = function (files) {
        var _this = this;
        var outputFiles = [];
        var errors = [];
        files.forEach(function (file) {
            if (_this.shouldBeTranspiled(file)) {
                try {
                    outputFiles.push({
                        name: file.name,
                        content: _this.transform(file.content),
                        mutated: file.mutated,
                        included: file.included,
                        transpiled: file.transpiled,
                        kind: core_1.FileKind.Text
                    });
                }
                catch (err) {
                    errors.push(file.name + ": " + err.message);
                }
            }
            else {
                outputFiles.push(file);
            }
        });
        return Promise.resolve(this.createResult(outputFiles, errors));
    };
    BabelTranspiler.prototype.shouldBeTranspiled = function (file) {
        return file.kind === core_1.FileKind.Text
            && file.transpiled
            && this.knownExtensions.indexOf(path.extname(file.name)) >= 0;
    };
    BabelTranspiler.prototype.transform = function (code) {
        var result = babel.transform(code, this.babelConfig).code;
        if (!result) {
            throw new Error('Could not transpile file with the Babel transform function');
        }
        return result;
    };
    BabelTranspiler.prototype.createResult = function (results, errorResults) {
        if (errorResults.length > 0) {
            return this.createErrorResult(errorResults.join(os_1.EOL));
        }
        return this.createSuccessResult(results);
    };
    BabelTranspiler.prototype.createErrorResult = function (error) {
        return {
            error: error,
            outputFiles: []
        };
    };
    BabelTranspiler.prototype.createSuccessResult = function (outputFiles) {
        return {
            error: null,
            outputFiles: outputFiles
        };
    };
    BabelTranspiler.prototype.getMappedLocation = function () {
        throw new Error('Not implemented');
    };
    return BabelTranspiler;
}());
exports.default = BabelTranspiler;
//# sourceMappingURL=BabelTranspiler.js.map